pub struct StandardChunkSet;Expand description
Standard Swarm chunk type set.
This set includes the two fundamental chunk types in the Swarm network:
- Content-addressed chunks (CAC) -
ChunkTypeId::CONTENT - Single-owner chunks (SOC) -
ChunkTypeId::SINGLE_OWNER
This is the default chunk set used by most Swarm nodes.
Example
ⓘ
use nectar_primitives::{ChunkTypeSet, ChunkTypeId, StandardChunkSet};
// Check support
assert!(StandardChunkSet::supports(ChunkTypeId::CONTENT));
assert!(StandardChunkSet::supports(ChunkTypeId::SINGLE_OWNER));
// Deserialize a chunk
let bytes: &[u8] = /* serialized chunk bytes */;
let chunk = StandardChunkSet::deserialize(bytes)?;Trait Implementations
Sourceimpl<const BODY_SIZE: usize> ChunkTypeSet<BODY_SIZE> for StandardChunkSet
impl<const BODY_SIZE: usize> ChunkTypeSet<BODY_SIZE> for StandardChunkSet
Sourcefn supports(type_id: ChunkTypeId) -> bool
fn supports(type_id: ChunkTypeId) -> bool
Check if a chunk type ID is supported by this set. Read more
Sourcefn deserialize(bytes: &[u8]) -> Result<AnyChunk<BODY_SIZE>>
fn deserialize(bytes: &[u8]) -> Result<AnyChunk<BODY_SIZE>>
Deserialize bytes into the appropriate chunk type. Read more
Sourcefn supported_types() -> &'static [ChunkTypeId]
fn supported_types() -> &'static [ChunkTypeId]
Get the list of all supported type IDs. Read more
Sourcefn format_supported_types() -> String
fn format_supported_types() -> String
Format the supported chunk types as a human-readable string. Read more
Sourceimpl Clone for StandardChunkSet
impl Clone for StandardChunkSet
Sourcefn clone(&self) -> StandardChunkSet
fn clone(&self) -> StandardChunkSet
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for StandardChunkSet
Sourceimpl Debug for StandardChunkSet
impl Debug for StandardChunkSet
Sourceimpl Default for StandardChunkSet
impl Default for StandardChunkSet
Sourcefn default() -> StandardChunkSet
fn default() -> StandardChunkSet
Returns the “default value” for a type. Read more