pub type DefaultAnyChunk = AnyChunk<DEFAULT_BODY_SIZE>;Expand description
Default polymorphic chunk.
Aliased Type
pub enum DefaultAnyChunk {
Content(ContentChunk<4096>),
SingleOwner(SingleOwnerChunk<4096>),
Custom {
type_id: ChunkTypeId,
address: SwarmAddress,
data: Bytes,
},
}Variants
Content(ContentChunk<4096>)
A content-addressed chunk (CAC).
SingleOwner(SingleOwnerChunk<4096>)
A single-owner chunk (SOC).
Custom
A custom chunk type (for extensibility).
This variant allows storing chunks of types not known at compile time. The raw bytes are preserved for potential later processing.